/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.archives.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmpWorkRecording;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmpWorkRecordingService;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * 员工工作履历信息表
 *
 * @author fxj
 * @date 2022-06-18 09:39:46
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tempworkrecording" )
@Tag(name = "员工工作履历信息表管理")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class TEmpWorkRecordingController {

    private final TEmpWorkRecordingService tEmpWorkRecordingService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param tEmpWorkRecording 员工工作履历信息表
     * @return
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page" )
    @PreAuthorize("@pms.hasPermission('archives_tempworkrecording_get')" )
    public R getTEmpWorkRecordingPage(Page page, TEmpWorkRecording tEmpWorkRecording) {
        return R.ok(tEmpWorkRecordingService.page(page, Wrappers.query(tEmpWorkRecording)));
    }


    /**
     * 通过id查询员工工作履历信息表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_tempworkrecording_get')" )
    public R getById(@PathVariable("id" ) Long id) {
        return R.ok(tEmpWorkRecordingService.getById(id));
    }

    /**
     * 新增员工工作履历信息表
     * @param tEmpWorkRecording 员工工作履历信息表
     * @return R
     */
    @Operation(summary = "新增员工工作履历信息表", description = "新增员工工作履历信息表")
    @SysLog("新增员工工作履历信息表" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('archives_tempworkrecording_add')" )
    public R save(@RequestBody TEmpWorkRecording tEmpWorkRecording) {
        return R.ok(tEmpWorkRecordingService.save(tEmpWorkRecording));
    }

    /**
     * 修改员工工作履历信息表
     * @param tEmpWorkRecording 员工工作履历信息表
     * @return R
     */
    @Operation(summary = "修改员工工作履历信息表", description = "修改员工工作履历信息表")
    @SysLog("修改员工工作履历信息表" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('archives_tempworkrecording_edit')" )
    public R updateById(@RequestBody TEmpWorkRecording tEmpWorkRecording) {
        return R.ok(tEmpWorkRecordingService.updateById(tEmpWorkRecording));
    }

    /**
     * 通过id删除员工工作履历信息表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除员工工作履历信息表", description = "通过id删除员工工作履历信息表")
    @SysLog("通过id删除员工工作履历信息表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('archives_tempworkrecording_del')" )
    public R removeById(@PathVariable Long id) {
        return R.ok(tEmpWorkRecordingService.removeById(id));
    }

}
