package com.yifu.cloud.plus.v1.check.utils;

import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.yifu.cloud.plus.v1.check.entity.TCheckIdCard;
import org.springframework.beans.factory.annotation.Value;

import java.util.HashMap;
import java.util.Map;

/**
 * @author hgw2
 * @description 测试身份证
 * @date 2022/5/7
 */
public class CheckIdCard {

     @Value("${canCheck}")
     private static boolean canCheck;

     private static final String APP_ID_ID_CARD = "oi0mucL4";

     private static final String APP_KEY_ID_CARD = "s4lW5JRA";

     private static final String API_URL_ID_CARD = "https://api.253.com/open/idcard/id-card-auth";

     private static JsonParser jsonParser = new JsonParser();

     public static void checkIdCard(TCheckIdCard checkIdCard) {

          if (canCheck) {
               // 1.调用身份信息校验api
               extracted(checkIdCard);
          } else {
               checkIdCard.setIsTrue(0);
               checkIdCard.setReason("nacos中checks.yaml的配置canCheck未开启！");
          }
     }

     // 核心调用
     private static void extracted(TCheckIdCard checkIdCard) {
          final JsonObject jsonObject = CheckIdCard.invokeIdCard(checkIdCard.getName(), checkIdCard.getIdCard());
          // 2.处理返回结果
          if (jsonObject != null) {
               //响应code码。200000：成功，其他失败
               String code = jsonObject.get("code").getAsString();
               if ("200000".equals(code) && jsonObject.get("data") != null) {
                    // 调用身份信息校验成功
                    // 解析结果数据，进行业务处理
                    // 校验状态码  200000：成功，其他失败
                    String resultStr = jsonObject.get("data").getAsJsonObject().get("result").getAsString();
                    if ("01".equals(resultStr)) {
                         checkIdCard.setIsTrue(1);
                         checkIdCard.setReason("正确");
                    } else {
                         checkIdCard.setIsTrue(0);
                         String remark = jsonObject.get("data").getAsJsonObject().get("remark").getAsString();
                         checkIdCard.setReason("调用身份信息校验失败,resultStr:" + resultStr + ",msg:" + remark);
                    }
               } else {
                    // 记录错误日志，正式项目中请换成log打印
                    checkIdCard.setIsTrue(0);
                    checkIdCard.setReason("调用身份信息校验失败,code:" + code + ",msg:" + jsonObject.get("message").getAsString());
               }
          } else {
               checkIdCard.setIsTrue(0);
               checkIdCard.setReason("接口无返回数据");
          }
     }

     private static JsonObject invokeIdCard(String name, String idNum) {
          Map<String, String> params = new HashMap<>();
          params.put("appId", APP_ID_ID_CARD);
          params.put("appKey", APP_KEY_ID_CARD);
          params.put("name", name);
          params.put("idNum", idNum);
          String result = HttpUtils.post(API_URL_ID_CARD, params);
          // 解析json,并返回结果
          return jsonParser.parse(result).getAsJsonObject();
     }
}
